============================
:class:`pyCTQW.MPI.GraphISO`
============================

.. currentmodule:: pyCTQW.MPI

.. autoclass:: pyCTQW.MPI.GraphISO
	:show-inheritance:


Method Summary
---------------

.. autosummary::
	:toctree: stub
	:template: method.rst

	GraphISO.AllIsomorphicQ
	GraphISO.GIcert
	GraphISO.getEigSolver
	GraphISO.getProperty
	GraphISO.isomorphicQ
	GraphISO.setEigSolver
	GraphISO.setProperties